@@ -4,10 +4,9 @@ use WWW::Mechanize::Firefox;
 use Object::Import;
 use Carp qw(croak);
 
-use vars qw($VERSION @CARP_NOT);
-$VERSION = '0.79';
+our $VERSION = '0.80';
 
-@CARP_NOT = (qw[
+our @CARP_NOT = (qw[
     WWW::Mechanize::Firefox
 ]);
 
